/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { WebElement, WebDriver, Locator } from 'selenium-webdriver';
import { Locators } from '../locators/locators';
/**
 * Default wrapper for webelement
 */
export declare abstract class AbstractElement extends WebElement {
    static readonly ctlKey: string;
    protected static driver: WebDriver;
    protected static locators: Locators;
    protected static versionInfo: {
        version: string;
        browser: string;
    };
    protected enclosingItem: WebElement;
    /**
     * Constructs a new element from a Locator or an existing WebElement
     * @param base WebDriver compatible Locator for the given element or a reference to an existing WeBelement
     * @param enclosingItem Locator or a WebElement reference to an element containing the element being constructed
     * this will be used to narrow down the search for the underlying DOM element
     */
    constructor(base: Locator | WebElement, enclosingItem?: WebElement | Locator);
    isEnabled(): Promise<boolean>;
    isSelected(): Promise<boolean>;
    /**
     * Wait for the element to become visible
     * @param timeout custom timeout for the wait
     * @returns thenable self reference
     */
    wait(timeout?: number): Promise<this>;
    /**
     * Return a reference to the WebElement containing this element
     */
    getEnclosingElement(): WebElement;
    static init(locators: Locators, driver: WebDriver, browser: string, version: string): void;
}
