/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ActivityBar, SideBarView } from '../..';
import { ElementWithContextMenu } from '../ElementWithContextMenu';
import { WebElement } from 'selenium-webdriver';
/**
 * Page object representing a view container item in the activity bar
 */
export declare class ViewControl extends ElementWithContextMenu {
    constructor(element: WebElement, bar: ActivityBar);
    /**
     * Opens the associated view if not already open
     * @returns Promise resolving to SideBarView object representing the opened view
     */
    openView(): Promise<SideBarView>;
    /**
     * Closes the associated view if not already closed
     * @returns Promise resolving when the view closes
     */
    closeView(): Promise<void>;
    /**
     * Returns the title of the associated view
     */
    getTitle(): Promise<string>;
}
