/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AbstractElement } from '../AbstractElement';
import { ProblemsView, OutputView, DebugConsoleView, TerminalView } from '../..';
/**
 * Page object for the bottom view panel
 */
export declare class BottomBarPanel extends AbstractElement {
    constructor();
    /**
     * Open/Close the bottom bar panel
     * @param open true to open. false to close
     * @returns Promise resolving when the view visibility is toggled
     */
    toggle(open: boolean): Promise<void>;
    /**
     * Open the Problems view in the bottom panel
     * @returns Promise resolving to a ProblemsView object
     */
    openProblemsView(): Promise<ProblemsView>;
    /**
     * Open the Output view in the bottom panel
     * @returns Promise resolving to OutputView object
     */
    openOutputView(): Promise<OutputView>;
    /**
     * Open the Debug Console view in the bottom panel
     * @returns Promise resolving to DebugConsoleView object
     */
    openDebugConsoleView(): Promise<DebugConsoleView>;
    /**
     * Open the Terminal view in the bottom panel
     * @returns Promise resolving to TerminalView object
     */
    openTerminalView(): Promise<TerminalView>;
    /**
     * Maximize the the bottom panel if not maximized
     * @returns Promise resolving when the maximize button is pressed
     */
    maximize(): Promise<void>;
    /**
     * Restore the the bottom panel if maximized
     * @returns Promise resolving when the restore button is pressed
     */
    restore(): Promise<void>;
    /**
     * Opens (or focuses) a tab in the bottom bar panel by its title.
     *
     * @param title The exact name of the tab to be opened or focused.
     * @returns A promise that resolves when the tab is opened or focused.
     */
    openTab(title: string): Promise<void>;
    private resize;
    closePanel(): Promise<void>;
}
