/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { WebElement } from 'selenium-webdriver';
import { AbstractElement } from '../AbstractElement';
/**
 * Page Object for Custom Style Modal Dialogs (non-native)
 */
export declare class ModalDialog extends AbstractElement {
    constructor();
    /**
     * Get the dialog's message in a Promise
     */
    getMessage(): Promise<string>;
    /**
     * Get the details message in a Promise
     */
    getDetails(): Promise<string>;
    /**
     * Get the list of buttons as WebElements
     *
     * @returns Promise resolving to Array of WebElement items representing the buttons
     */
    getButtons(): Promise<WebElement[]>;
    /**
     * Push a button with given title if it exists
     *
     * @param title title/text of the button
     */
    pushButton(title: string): Promise<void>;
    /**
     * Close the dialog using the 'cross' button
     */
    close(): Promise<void>;
}
