/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { TextEditor, Menu, MenuItem, DebugConsoleView } from '../..';
import { WebElement } from 'selenium-webdriver';
/**
 * Page object representing the content assistant
 */
export declare class ContentAssist extends Menu {
    constructor(parent: TextEditor | DebugConsoleView);
    /**
     * Get content assist item by name/text, scroll through the list
     * until the item is found, or the end is reached
     *
     * @param name name/text to search by
     * @returns Promise resolving to ContentAssistItem object if found, undefined otherwise
     */
    getItem(name: string): Promise<ContentAssistItem | undefined>;
    /**
     * Get all visible content assist items
     * @returns Promise resolving to array of ContentAssistItem objects
     */
    getItems(): Promise<ContentAssistItem[]>;
    /**
     * Find if the content assist is still loading the suggestions
     * @returns promise that resolves to true when suggestions are done loading,
     * to false otherwise
     */
    isLoaded(): Promise<boolean>;
}
/**
 * Page object for a content assist item
 */
export declare class ContentAssistItem extends MenuItem {
    constructor(item: WebElement, contentAssist: ContentAssist);
    getLabel(): Promise<string>;
}
