/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Editor, InputBox, WebView } from '../..';
/**
 * Page object for custom editors
 */
export declare class CustomEditor extends Editor {
    /**
     * Get the WebView object contained in the editor
     * @returns WebView page object
     */
    getWebView(): WebView;
    /**
     * Check if the editor has unsaved changes
     * @returns Promise resolving to true if there are unsaved changes, false otherwise
     */
    isDirty(): Promise<boolean>;
    /**
     * Save the editor
     */
    save(): Promise<void>;
    /**
     * Open the Save as prompt
     *
     * @returns InputBox serving as a simple file dialog
     */
    saveAs(): Promise<InputBox>;
}
