"use strict";
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomEditor = void 0;
const selenium_webdriver_1 = require("selenium-webdriver");
const __1 = require("../..");
/**
 * Page object for custom editors
 */
class CustomEditor extends __1.Editor {
    /**
     * Get the WebView object contained in the editor
     * @returns WebView page object
     */
    getWebView() {
        return new __1.WebView();
    }
    /**
     * Check if the editor has unsaved changes
     * @returns Promise resolving to true if there are unsaved changes, false otherwise
     */
    async isDirty() {
        const tab = await this.getTab();
        const klass = await tab.getAttribute('class');
        return klass.includes('dirty');
    }
    /**
     * Save the editor
     */
    async save() {
        const tab = await this.getTab();
        await tab.sendKeys(selenium_webdriver_1.Key.chord(CustomEditor.ctlKey, 's'));
    }
    /**
     * Open the Save as prompt
     *
     * @returns InputBox serving as a simple file dialog
     */
    async saveAs() {
        const tab = await this.getTab();
        await tab.sendKeys(selenium_webdriver_1.Key.chord(CustomEditor.ctlKey, selenium_webdriver_1.Key.SHIFT, 's'));
        return await __1.InputBox.create();
    }
}
exports.CustomEditor = CustomEditor;
//# sourceMappingURL=CustomEditor.js.map