"use strict";
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiffEditor = void 0;
const Editor_1 = require("./Editor");
const TextEditor_1 = require("./TextEditor");
const EditorView_1 = require("./EditorView");
/**
 * Page object representing a diff editor
 */
class DiffEditor extends Editor_1.Editor {
    /**
     * Gets the text editor corresponding to the originalside.
     * (The left side of the diff editor)
     * @returns Promise resolving to TextEditor object
     */
    async getOriginalEditor() {
        const element = await this.getEnclosingElement().findElement(DiffEditor.locators.DiffEditor.originalEditor);
        return new TextEditor_1.TextEditor(new EditorView_1.EditorView(), element);
    }
    /**
     * Gets the text editor corresponding to the modified side.
     * (The right side of the diff editor)
     * @returns Promise resolving to TextEditor object
     */
    async getModifiedEditor() {
        const element = await this.getEnclosingElement().findElement(DiffEditor.locators.DiffEditor.modifiedEditor);
        return new TextEditor_1.TextEditor(new EditorView_1.EditorView(), element);
    }
}
exports.DiffEditor = DiffEditor;
//# sourceMappingURL=DiffEditor.js.map