/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ExtensionEditorView, WebView } from '../..';
export declare class ExtensionEditorDetailsSection extends ExtensionEditorView {
    /**
     * Get all categories of extension.
     * @returns Promise resolving categories of extension.
     */
    getCategories(): Promise<string[]>;
    /**
     * Get all resources of extension.
     * @returns Promise resolving resources of extension.
     */
    getResources(): Promise<string[]>;
    /**
     * Get content of More Info section.
     * @returns Promise resolving content of 'More Info' section.
     */
    getMoreInfo(): Promise<{
        [key: string]: string;
    }>;
    /**
     * Get value of specific attribute from 'More Info' section.
     * @param key Name of attribute.
     * @returns Promise resolving value for specified attribute.
     */
    getMoreInfoItem(key: string): Promise<string>;
    /**
     * Get readme WebView element.
     * @returns Promise resolving WebView element containing the readme content.
     */
    getReadme(): Promise<WebView>;
    /**
     * Get readme content as a string.
     * @returns Promise resolving the text content of the readme.
     */
    getReadmeContent(): Promise<string>;
    /**
     * Get version of extension.
     * @returns Promise resolving version of extension.
     */
    getVersion(): Promise<string>;
}
