/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Editor, EditorGroup, EditorView } from '../..';
export declare class ExtensionEditorView extends Editor {
    constructor(view?: EditorView | EditorGroup);
    /**
     * Get name of extension.
     * @returns Promise resolving name of extension.
     */
    getName(): Promise<string>;
    /**
     * Get version of extension.
     * @returns Promise resolving version of extension.
     * @deprecated It is no more actual for VS Code 1.96+. Version can accessed using ExtensionEditorDetailsSection.
     */
    getVersion(): Promise<string>;
    /**
     * Get publisher of extension.
     * @returns Promise resolving publisher of extension.
     */
    getPublisher(): Promise<string>;
    /**
     * Get description of extension.
     * @returns Promise description name of opened extension.
     */
    getDescription(): Promise<string>;
    /**
     * Get count of extension.
     * @returns Promise resolving count of opened extension.
     */
    getCount(): Promise<string>;
    /**
     * Get available tabs.
     * @returns Promise resolving tabs of opened extension.
     */
    getTabs(): Promise<string[]>;
    /**
     * Switch to different tab.
     * @param tabName Name of required tab to be switched on.
     * @returns Promise resolving to true if tabs were switched successfully, false otherwise.
     */
    switchToTab(tabName: string): Promise<boolean>;
    /**
     * Get name of opened tab.
     * @returns Promise resolving name of opened tab.
     */
    getActiveTab(): Promise<string>;
}
