/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Menu, MenuItem } from '../..';
import { WebElement } from 'selenium-webdriver';
/**
 * Object representing a context menu
 */
export declare class ContextMenu extends Menu {
    constructor(containingElement: WebElement);
    /**
     * Get context menu item by name
     * @param name name of the item to search by
     * @returns Promise resolving to ContextMenuItem object
     */
    getItem(name: string): Promise<ContextMenuItem | undefined>;
    /**
     * Get all context menu items
     * @returns Promise resolving to array of ContextMenuItem objects
     */
    getItems(): Promise<ContextMenuItem[]>;
    /**
     * Close the context menu
     * @returns Promise resolving when the menu is closed
     */
    close(): Promise<void>;
    /**
     * Wait for the menu to appear and load all its items
     */
    wait(timeout?: number): Promise<this>;
}
/**
 * Object representing an item of a context menu
 */
export declare class ContextMenuItem extends MenuItem {
    constructor(item: WebElement, parent: Menu);
    select(): Promise<Menu | undefined>;
    getLabel(): Promise<string>;
    private isNesting;
}
