"use strict";
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuItem = void 0;
const AbstractElement_1 = require("../AbstractElement");
/**
 * Abstract element representing a menu item
 */
class MenuItem extends AbstractElement_1.AbstractElement {
    parent;
    label;
    /**
     * Use the given menu item: Opens the submenu if the item has children,
     * otherwise simply click the item.
     *
     * @returns Menu object representing the submenu if the item has children, void otherwise.
     */
    async select() {
        await this.click();
        await new Promise((res) => setTimeout(res, 500));
        return undefined;
    }
    /**
     * Return the Menu object representing the menu this item belongs to
     */
    getParent() {
        return this.parent;
    }
    /**
     * Returns the label of the menu item
     */
    getLabel() {
        return this.label;
    }
}
exports.MenuItem = MenuItem;
//# sourceMappingURL=MenuItem.js.map