/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { WindowControls, ContextMenu } from '../..';
import { Menu } from './Menu';
import { MenuItem } from './MenuItem';
/**
 * Page object representing the custom VS Code title bar
 */
export declare class TitleBar extends Menu {
    constructor();
    /**
     * Get title bar item by name
     * @param name name of the item to search by
     * @returns Promise resolving to TitleBarItem object
     */
    getItem(name: string): Promise<TitleBarItem | undefined>;
    /**
     * Get all title bar items
     * @returns Promise resolving to array of TitleBarItem objects
     */
    getItems(): Promise<TitleBarItem[]>;
    /**
     * Get the window title
     * @returns Promise resolving to the window title
     */
    getTitle(): Promise<string>;
    /**
     * Get a reference to the WindowControls
     * @deprecated Window Control is no more available in a DOM of Visual Studio Code
     */
    getWindowControls(): WindowControls;
}
/**
 * Page object representing an item of the custom VS Code title bar
 */
export declare class TitleBarItem extends MenuItem {
    constructor(label: string, parent: Menu);
    select(): Promise<ContextMenu>;
}
