/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ElementWithContextMenu } from '../ElementWithContextMenu';
import { AbstractElement } from '../AbstractElement';
import { By, SideBarView } from '../..';
/**
 * Page object representing the top (title) part of a side bar view
 */
export declare class ViewTitlePart extends ElementWithContextMenu {
    constructor(view?: SideBarView);
    /**
     * Returns the displayed title of the view
     * @returns Promise resolving to displayed title
     */
    getTitle(): Promise<string>;
    /**
     * Finds action buttons inside the view title part
     * @returns Promise resolving to array of TitleActionButton objects
     */
    getActions(): Promise<TitleActionButton[]>;
    /**
     * Finds an action button by title
     * @param title title of the button to search for
     * @returns Promise resolving to TitleActionButton object
     */
    getAction(title: string): Promise<TitleActionButton>;
}
/**
 * Page object representing a button inside the view title part
 */
export declare class TitleActionButton extends AbstractElement {
    constructor(actionConstructor: By, viewTitle: ViewTitlePart);
    /**
     * Get title of the button
     */
    getTitle(): Promise<string>;
}
