/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { SideBarView } from '../SideBarView';
import { DebugBreakpointSection } from '../tree/debug/DebugBreakpointSection';
import { DebugCallStackSection } from '../tree/debug/DebugCallStackSection';
import { DebugVariableSection } from '../tree/debug/DebugVariablesSection';
import { WatchSection } from '../tree/debug/WatchSection';
/**
 * Page object representing the Run/Debug view in the side bar
 */
export declare class DebugView extends SideBarView {
    /**
     * Get the title of the selected launch configuration
     * @returns Promise resolving to the title
     * @deprecated For VS Code 1.88+ this method won't be working any more
     */
    getLaunchConfiguration(): Promise<string>;
    /**
     * Get titles of all available launch configurations
     * @returns Promise resolving to list of titles
     */
    getLaunchConfigurations(): Promise<string[]>;
    getVariablesSection(): Promise<DebugVariableSection>;
    /**
     * Get section which holds information about breakpoints.
     * @returns DebugBreakpointSection page object
     */
    getBreakpointSection(): Promise<DebugBreakpointSection>;
    /**
     * Select a given launch configuration
     * @param title title of the configuration to select
     */
    selectLaunchConfiguration(title: string): Promise<void>;
    /**
     * Start Debugging using the current launch configuration
     */
    start(): Promise<void>;
    /**
     * Get Call Stack section
     * @returns CallStackSection page object
     */
    getCallStackSection(): Promise<DebugCallStackSection>;
    /**
     * Get Watch section
     * @returns WatchSection page object
     */
    getWatchSection(): Promise<WatchSection>;
}
