/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ScmView, ScmProvider, ScmChange } from './ScmView';
import { ContextMenu } from '../../menu/ContextMenu';
/**
 * New SCM view for code 1.47 onwards
 */
export declare class NewScmView extends ScmView {
    getProviders(): Promise<ScmProvider[]>;
}
/**
 * Implementation for a single SCM provider
 */
export declare class SingleScmProvider extends ScmProvider {
    /**
     * There is no title available for a single provider
     */
    getTitle(): Promise<string>;
    /**
     * No title available for single provider
     */
    getType(): Promise<string>;
    takeAction(title: string): Promise<boolean>;
    private getProviderHeaderActions;
    openMoreActions(): Promise<ContextMenu>;
    getChanges(staged?: boolean): Promise<ScmChange[]>;
}
/**
 * Implementation of an SCM provider when multiple providers are available
 */
export declare class MultiScmProvider extends ScmProvider {
    takeAction(title: string): Promise<boolean>;
    openMoreActions(): Promise<ContextMenu>;
    commitChanges(message: string): Promise<void>;
    getChanges(staged?: boolean): Promise<ScmChange[]>;
    getChangeCount(staged?: boolean): Promise<number>;
}
