"use strict";
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomTreeItem = void 0;
const ViewItem_1 = require("../../ViewItem");
/**
 * View item in a custom-made content section (e.g. an extension tree view)
 */
class CustomTreeItem extends ViewItem_1.TreeItem {
    constructor(element, viewPart) {
        super(element, viewPart);
    }
    async getLabel() {
        return await this.findElement(CustomTreeItem.locators.CustomTreeSection.itemLabel).getText();
    }
    async getTooltip() {
        return await this.getAttribute(CustomTreeItem.locators.CustomTreeItem.tooltipAttribute);
    }
    async getDescription() {
        return await this.findElement(CustomTreeItem.locators.CustomTreeItem.description).getText();
    }
    async isExpanded() {
        const attr = await this.getAttribute(CustomTreeItem.locators.CustomTreeItem.expandedAttr);
        return attr === CustomTreeItem.locators.CustomTreeItem.expandedValue;
    }
    async getChildren() {
        const rows = await this.getChildItems(CustomTreeItem.locators.DefaultTreeSection.itemRow);
        const items = await Promise.all(rows.map(async (row) => new CustomTreeItem(row, this.enclosingItem).wait()));
        return items;
    }
    async isExpandable() {
        const attr = await this.getAttribute(CustomTreeItem.locators.CustomTreeItem.expandedAttr);
        return attr !== null;
    }
}
exports.CustomTreeItem = CustomTreeItem;
//# sourceMappingURL=CustomTreeItem.js.map