/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { TreeSection } from '../TreeSection';
import { TreeItem } from '../../ViewItem';
import { WebElement } from 'selenium-webdriver';
import { CustomTreeItem, ViewContent } from '../../../..';
export type GenericCustomTreeItemConstructor<T extends TreeItem> = {
    new (rootElement: WebElement, tree: TreeSection): T;
};
/**
 * Generic custom tree view, e.g. contributed by an extension
 */
export declare class GenericCustomTreeSection<T extends TreeItem> extends TreeSection {
    private _viewContent;
    private _itemConstructor;
    constructor(panel: WebElement, _viewContent: ViewContent, itemConstructor: GenericCustomTreeItemConstructor<T>);
    private get viewContent();
    private get itemConstructor();
    getVisibleItems(): Promise<T[]>;
    findItem(labelOrPredicate: string | ((el: T) => PromiseLike<boolean> | boolean), maxLevel?: number): Promise<T | undefined>;
    private getContainer;
}
/**
 * Custom tree view, e.g. contributed by an extension
 */
export declare class CustomTreeSection extends GenericCustomTreeSection<CustomTreeItem> {
    constructor(panel: WebElement, viewContent: ViewContent);
}
