/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { WebElement } from 'selenium-webdriver';
import { TreeSection } from '../TreeSection';
import { CustomTreeItem } from '../custom/CustomTreeItem';
import { SectionBreakpoint } from './SectionBreakpoint';
export declare class BreakpointSectionItem extends CustomTreeItem {
    constructor(element: WebElement, viewPart: TreeSection);
    /**
     * Get breakpoint element which has context menu.
     * @returns SectionBreakpoint page object
     */
    getBreakpoint(): Promise<SectionBreakpoint>;
    /**
     * Get status of the breakpoint.
     * @returns boolean indicating status
     */
    isBreakpointEnabled(): Promise<boolean>;
    /**
     * Change breakpoint status to desired state.
     * @param value new state
     */
    setBreakpointEnabled(value: boolean): Promise<void>;
    getLabel(): Promise<string>;
    /**
     * Get breakpoint file path. Empty string is returned if path is not specified.
     * @returns file path of breakpoint or empty string
     */
    getBreakpointFilePath(): Promise<string>;
    /**
     * Get line number of the breakpoint.
     * @returns number indicating line position in file
     */
    getBreakpointLine(): Promise<number>;
}
