"use strict";
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.WatchSectionItem = void 0;
const CustomTreeItem_1 = require("../custom/CustomTreeItem");
class WatchSectionItem extends CustomTreeItem_1.CustomTreeItem {
    constructor(element, viewPart) {
        super(element, viewPart);
    }
    /**
     * Get label of the Watch section item.
     * @returns a promise resolving to Watch section item label string
     */
    async getLabel() {
        const name = await this.findElement(WatchSectionItem.locators.WatchSectionItem.label);
        return await name?.getAttribute('textContent');
    }
    /**
     * Get value of the Watch section item.
     * @returns a promise resolving to Watch section value label string
     */
    async getValue() {
        const value = await this.findElement(WatchSectionItem.locators.WatchSectionItem.value);
        return await value.getText();
    }
    /**
     * Remove item from Watch section.
     */
    async remove() {
        const button = await this.getActionButton(WatchSectionItem.locators.WatchSectionItem.remove);
        await button?.click();
    }
}
exports.WatchSectionItem = WatchSectionItem;
//# sourceMappingURL=WatchSectionItem.js.map