"use strict";
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultTreeItem = void 0;
const ViewItem_1 = require("../../ViewItem");
const NullAttributeError_1 = require("../../../../errors/NullAttributeError");
/**
 * Default tree item base on the items in explorer view
 */
class DefaultTreeItem extends ViewItem_1.TreeItem {
    constructor(element, viewPart) {
        super(element, viewPart);
    }
    async getLabel() {
        const value = await this.getAttribute(DefaultTreeItem.locators.DefaultTreeSection.itemLabel);
        if (value === null) {
            throw new NullAttributeError_1.NullAttributeError(`${this.constructor.name}.getLabel returned null`);
        }
        return value;
    }
    async getTooltip() {
        const tooltip = await this.findElement(DefaultTreeItem.locators.DefaultTreeItem.tooltip);
        return await tooltip.getAttribute(DefaultTreeItem.locators.DefaultTreeItem.labelAttribute);
    }
    async isExpanded() {
        const twistieClass = await this.findElement(DefaultTreeItem.locators.DefaultTreeItem.twistie).getAttribute('class');
        return twistieClass.indexOf('collapsed') < 0;
    }
    async getChildren() {
        const rows = await this.getChildItems(DefaultTreeItem.locators.DefaultTreeSection.itemRow);
        const items = await Promise.all(rows.map(async (row) => new DefaultTreeItem(row, this.enclosingItem).wait()));
        return items;
    }
    async isExpandable() {
        const twistieClass = await this.findElement(DefaultTreeItem.locators.DefaultTreeItem.twistie).getAttribute('class');
        return twistieClass.indexOf('collapsible') > -1;
    }
}
exports.DefaultTreeItem = DefaultTreeItem;
//# sourceMappingURL=DefaultTreeItem.js.map