/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AbstractElement } from '../AbstractElement';
/**
 * Page object for the Debugger Toolbar
 */
export declare class DebugToolbar extends AbstractElement {
    constructor();
    /**
     * Wait for the debug toolbar to appear and instantiate it.
     * Assumes that debug session is already starting and it is just
     * a matter of waiting for the toolbar to appear.
     *
     * @param timeout max time to wait in milliseconds, default 5000
     */
    static create(timeout?: number): Promise<DebugToolbar>;
    /**
     * Wait for the execution to pause at the next breakpoint
     */
    waitForBreakPoint(timeout?: number): Promise<void>;
    /**
     * Click Continue
     */
    continue(): Promise<void>;
    /**
     * Click Disconnect
     */
    disconnect(): Promise<void>;
    /**
     * Click Pause
     */
    pause(): Promise<void>;
    /**
     * Click Step Over
     */
    stepOver(): Promise<void>;
    /**
     * Click Step Into
     */
    stepInto(): Promise<void>;
    /**
     * Click Step Out
     */
    stepOut(): Promise<void>;
    /**
     * Click Restart
     */
    restart(): Promise<void>;
    /**
     * Click Stop
     */
    stop(): Promise<void>;
    private getButton;
}
