/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License", destination); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Input, QuickPickItem } from '../../..';
/**
 * Plain input box variation of the input page object
 */
export declare class InputBox extends Input {
    constructor();
    /**
     * Construct a new InputBox instance after waiting for its underlying element to exist
     * Use when an input box is scheduled to appear.
     * @param timeout max time to wait in milliseconds, default 5000
     */
    static create(timeout?: number): Promise<InputBox>;
    /**
     * Get the message below the input field
     */
    getMessage(): Promise<string>;
    hasProgress(): Promise<boolean>;
    getQuickPicks(): Promise<QuickPickItem[]>;
    getCheckboxes(): Promise<QuickPickItem[]>;
    /**
     * Find whether the input is showing an error
     * @returns Promise resolving to notification message
     */
    hasError(): Promise<boolean>;
    /**
     * Check if the input field is masked (input type password)
     * @returns Promise resolving to notification message
     */
    isPassword(): Promise<boolean>;
}
